aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/java/org/apache/fop/cli/CommandLineOptions.java11
1 files changed, 10 insertions, 1 deletions
diff --git a/src/java/org/apache/fop/cli/CommandLineOptions.java b/src/java/org/apache/fop/cli/CommandLineOptions.java
index 65391d79f..7e7082e85 100644
--- a/src/java/org/apache/fop/cli/CommandLineOptions.java
+++ b/src/java/org/apache/fop/cli/CommandLineOptions.java
@@ -462,11 +462,16 @@ public class CommandLineOptions implements Constants {
}
private void setLogLevel(String level) {
// Set the evel for future loggers.
LogFactory.getFactory().setAttribute("level", level);
if (log instanceof CommandLineLogger) {
// Set the level for the logger creates already.
((CommandLineLogger) log).setLogLevel(level);
+ } else {
+ log.warn("Setting the log level to debug probably failed.");
+ log.warn("Configure the log level using Java system properties,");
+ log.warn("or use FOP's command line logger,");
+ log.warn("which is the default on the command line.");
}
}
@@ -821,6 +826,10 @@ public class CommandLineOptions implements Constants {
log.info("svg");
log.info("output file: " + outfile.toString());
break;
+ case RENDER_XML:
+ log.info("area tree");
+ log.info("output file: " + outfile.toString());
+ break;
default:
log.info("unknown input type");
}
@@ -462,11 +462,16 @@ public class CommandLineOptions implements Constants {
}
private void setLogLevel(String level) {
- // Set the evel for future loggers.
+ // Set the level for future loggers.
LogFactory.getFactory().setAttribute("level", level);
if (log instanceof CommandLineLogger) {